@@ -1508,6 +1508,67 @@ plt({
 	nrows         => 2,
 	scale         => 2
 });
+
+my @t;
+for (my $t = 0.01; $t <= 10; $t += 0.01) {
+	push @t, $t;
+}
+plt({
+	execute       => 0,
+	fh            => $fh,
+	data          => [
+		[ # plot 0
+			[@t],              # x coordinates
+			[map {sin($_)} @t] # y coordinates
+		],
+		[ # plot 1
+			[@t],
+			[map {exp($_)} @t]
+		]
+	],
+	'output.file' => 'output.images/twinx.arr.png',
+	'plot.type'   => 'plot',
+	'set.options' => [
+		'color = "blue"', # plot 0
+		'color = "red"'   # plot 1
+	],
+	tick_params => 'axis = "y", labelcolor = "blue"',
+	ylabel      => '"sin", color="blue"', # applies to base ax object
+	'twinx.args'  => {
+		1 => { # automatically knows that plot 1 is twinned on x
+			tick_params => 'axis = "y", labelcolor = "red"',
+			ylabel      => '"exp", color="red"',
+		}
+	},
+});
+plt({
+	execute       => 0,
+	fh            => $fh,
+	data          => {
+		'sin' => [ # plot 0
+			[@t],              # x coordinates
+			[map {sin($_)} @t] # y coordinates
+		],
+		'exp' => [ # plot 1
+			[@t],
+			[map {exp($_)} @t]
+		]
+	},
+	'output.file' => 'output.images/twinx.hash.png',
+	'plot.type'   => 'plot',
+	'set.options' => {
+		'sin' => 'color = "blue"',
+		'exp' => 'color = "red"'
+	},
+	tick_params => 'axis = "y", labelcolor = "blue"',
+	ylabel      => '"sin", color="blue"', # applies to base ax object
+	'twinx.args'  => {
+		'exp' => { # automatically knows that plot is twinx
+			tick_params => 'axis = "y", labelcolor = "red"',
+			ylabel      => '"exp", color="red"',
+		}
+	},
+});
 plt({
 	fh                => $fh,
 	execute           => 1,
